@@ -19,6 +19,7 @@ from biosimulators_utils.sedml import validation
 from biosimulators_utils.sedml.data_model import (Task, ModelLanguage, ModelAttributeChange,  # noqa: F401
                                                   UniformTimeCourseSimulation, Variable)
 from biosimulators_utils.sedml.exec import exec_sed_doc
+from biosimulators_utils.utils.core import raise_errors_warnings
 import functools
 import warnings
 
@@ -95,13 +96,20 @@ def exec_sed_task(sed_task, variables, log=None):
     """
     log = log or TaskLog()
 
-    validation.validate_task(sed_task)
-    validation.validate_model_language(sed_task.model.language, ModelLanguage.BNGL)
-    validation.validate_model_change_types(sed_task.model.changes, (ModelAttributeChange, ))
-    validation.validate_model_changes(sed_task.model.changes)
-    validation.validate_simulation_type(sed_task.simulation, (UniformTimeCourseSimulation, ))
-    validation.validate_uniform_time_course_simulation(sed_task.simulation)
-    validation.validate_data_generator_variables(variables)
+    raise_errors_warnings(validation.validate_task(sed_task),
+                          error_summary='Task `{}` is invalid.'.format(sed_task.id))
+    raise_errors_warnings(validation.validate_model_language(sed_task.model.language, ModelLanguage.BNGL),
+                          error_summary='Language for model `{}` is not supported.'.format(sed_task.model.id))
+    raise_errors_warnings(validation.validate_model_change_types(sed_task.model.changes, (ModelAttributeChange, )),
+                          error_summary='Changes for model `{}` are not supported.'.format(sed_task.model.id))
+    raise_errors_warnings(*validation.validate_model_changes(sed_task.model),
+                          error_summary='Changes for model `{}` are invalid.'.format(sed_task.model.id))
+    raise_errors_warnings(validation.validate_simulation_type(sed_task.simulation, (UniformTimeCourseSimulation, )),
+                          error_summary='{} `{}` is not supported.'.format(sed_task.simulation.__class__.__name__, sed_task.simulation.id))
+    raise_errors_warnings(*validation.validate_simulation(sed_task.simulation),
+                          error_summary='Simulation `{}` is invalid.'.format(sed_task.simulation.id))
+    raise_errors_warnings(*validation.validate_data_generator_variables(variables),
+                          error_summary='Data generator variables for task `{}` are invalid.'.format(sed_task.id))
 
     # read the model from the BNGL file
     bionetgen_task = read_task(sed_task.model.source)
@@ -117,7 +125,7 @@ def exec_sed_task(sed_task, variables, log=None):
     add_variables_to_model(bionetgen_task.model, variables)
 
     # apply the SED algorithm and its parameters to the BioNetGen task
-    add_simulation_to_task(bionetgen_task, sed_task.simulation)
+    alg_kisao_id = add_simulation_to_task(bionetgen_task, sed_task.simulation)
 
     # execute the task
     observable_results = exec_bionetgen_task(bionetgen_task)
@@ -128,7 +136,7 @@ def exec_sed_task(sed_task, variables, log=None):
         variable_results[key] = variable_results[key][-(sed_task.simulation.number_of_points + 1):]
 
     # log action
-    log.algorithm = sed_task.simulation.algorithm.kisao_id
+    log.algorithm = alg_kisao_id
     log.simulator_details = {
         'actions': bionetgen_task.actions,
     }
